@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: asttypes.mli,v 1.5 2002/01/14 15:50:18 filliatr Exp $ *)
+(* $Id: asttypes.mli,v 1.6 2004/10/12 12:29:19 filliatr Exp $ *)
 
 (* Auxiliary a.s.t. types used by parsetree and typedtree. *)
 
@@ -19,6 +19,9 @@ type constant =
   | Const_char of char
   | Const_string of string
   | Const_float of string
+  | Const_int32 of int32
+  | Const_int64 of int64
+  | Const_nativeint of nativeint
 
 type rec_flag = Nonrecursive | Recursive | Default
 
