@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: lexer.mli,v 1.5 2002/01/14 15:50:18 filliatr Exp $ *)
+(* $Id: lexer.mli,v 1.6 2004/10/12 12:29:19 filliatr Exp $ *)
 
 (* The lexical analyzer *)
 
@@ -24,9 +24,10 @@ type error =
   | Unterminated_string
   | Unterminated_string_in_comment
   | Keyword_as_label of string
+  | Literal_overflow of string
 ;;
 
-exception Error of error * int * int
+exception Error of error * Location.t
 
 open Format
 
