@@ -10,15 +10,33 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: location.mli,v 1.5 2002/01/14 15:50:18 filliatr Exp $ *)
+(* $Id: location.mli,v 1.6 2004/10/12 12:29:19 filliatr Exp $ *)
+
+(* Source code locations (ranges of positions), used in parsetree. *)
 
-(* Source code locations, used in parsetree *)
 open Format
 
-type t =
-  { loc_start: int; loc_end: int; loc_ghost: bool }
+type t = {
+  loc_start: Lexing.position;
+  loc_end: Lexing.position;
+  loc_ghost: bool;
+}
+
+(* Note on the use of Lexing.position in this module.
+   If [pos_fname = ""], then use [!input_name] instead.
+   If [pos_lnum = -1], then [pos_bol = 0]. Use [pos_cnum] and
+     re-parse the file to get the line and character numbers.
+   Else all fields are correct.
+*)
+
+val none : t
+(** An arbitrary value of type [t]; describes an empty ghost range. *)
+val init : Lexing.lexbuf -> string -> unit
+(** Set the file name and line number of the [lexbuf] to be the start
+    of the named file. *)
+val curr : Lexing.lexbuf -> t
+(** Get the location of the current token from the [lexbuf]. *)
 
-val none: t
 val symbol_rloc: unit -> t
 val symbol_gloc: unit -> t
 val rhs_loc: int -> t
@@ -26,10 +44,11 @@ val rhs_loc: int -> t
 val input_name: string ref
 val input_lexbuf: Lexing.lexbuf option ref
 
+val get_pos_info : Lexing.position -> string * int * int (* file, line, char *)
 val print: formatter -> t -> unit
 val print_warning: t -> formatter -> Warnings.t -> unit
 val prerr_warning: t -> Warnings.t -> unit
 val echo_eof: unit -> unit
 val reset: unit -> unit
 
-val highlight_locations: t -> t -> bool
+val highlight_locations: formatter -> t -> t -> bool
