@@ -14,7 +14,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(*i $Id: output.ml,v 1.64 2004/09/23 09:20:16 filliatr Exp $ i*)
+(*i $Id: output.ml,v 1.65 2005/11/04 13:30:03 filliatr Exp $ i*)
 
 (*i*)
 open Printf
@@ -102,7 +102,7 @@ let latex_header opt =
     output_string "\\usepackage";
     if opt <> "" then output_string (sprintf "[%s]" opt);
     output_string "{ocamlweb}\n";
-    output_string "\\pagestyle{ocamlweb}\n";
+    output_string "\\pagestyle{headings}\n";
     Queue.iter (fun s -> output_string s; output_string "\n") preamble;
     output_string "\\begin{document}\n"
   end;
